"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LinearShadowView = LinearShadowView;
exports.ShadowView = ShadowView;
var _react = require("react");
var _utils = require("../utils.js");
var _constants = require("../constants.js");
var _reactNativeReanimated = _interopRequireDefault(require("react-native-reanimated"));
var _reactNativeSkia = require("@shopify/react-native-skia");
var _ShadowLinearGradientFill = _interopRequireDefault(require("./ShadowLinearGradientFill.js"));
var _CornerRadii = require("./CornerRadii.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * A unified interface for both "solid" (InnerShadow) and "linear" (LinearShadow).
 * We automatically detect "linear mode" by checking if the user provides
 * gradient props (colors, from, to, etc.).
 */function UnifiedShadowView(props) {
  /** 1) Extract essential props & compute defaults */
  const backgroundColor = (0, _utils.getBackgroundColor)(props);
  const shadowProps = (0, _react.useMemo)(() => (0, _utils.getShadowProperty)(props), [props]);
  const isLinear = (0, _utils.isLinearProps)(props);

  /**
   * If isReflectedLightEnabled is undefined, default to props.inset
   * for the typical "inset = highlight" usage.
   */
  const isReflectedLightEnabled = props.isReflectedLightEnabled ?? props.inset;

  /** 2) Extract width/height from style if provided */
  const styleWidth = props.style && (Number.isNaN(Number(props.style.width)) ? 0 : Number(props.style.width));
  const styleHeight = props.style && (Number.isNaN(Number(props.style.height)) ? 0 : Number(props.style.height));
  /** 3) Local state for measuring if needed */
  const [layoutSize, setLayoutSize] = (0, _react.useState)({
    width: 0,
    height: 0
  });

  /**
   * Only measure if user hasn't explicitly set width/height in style,
   * to avoid repeated re-renders.
   */
  const onLayout = (0, _react.useCallback)(e => {
    if (!styleWidth || !styleHeight) {
      const {
        width,
        height
      } = e.nativeEvent.layout;
      if (width !== layoutSize.width || height !== layoutSize.height) {
        setLayoutSize({
          width,
          height
        });
      }
    }
  }, [styleWidth, styleHeight, layoutSize]);

  /** 4) Final dimensions we use for the Canvas */
  const finalWidth = styleWidth ? styleWidth : layoutSize.width;
  const finalHeight = styleHeight ? styleHeight : layoutSize.height;

  /**
   * We only render the Canvas if we have a valid size
   * (prevents flicker or wasted draws when size = 0).
   */
  const canRenderCanvas = finalWidth > 0 && finalHeight > 0;

  /** 5) Memoize style objects if needed */
  const canvasStyle = (0, _react.useMemo)(() => (0, _utils.createStyles)({
    width: finalWidth,
    height: finalHeight
  }), [finalWidth, finalHeight]);
  const outerShadowOffset = (0, _react.useMemo)(() => (0, _utils.createOuterShadowOffset)({
    inset: !!props.inset,
    ...shadowProps
  }), [shadowProps, props.inset]);

  /** 6) Render Flow */
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeReanimated.default.View, {
    ...props,
    style: [props.style, _constants.COMMON_STYLES.canvasWrapper, outerShadowOffset // Possibly sets outer drop-shadow if needed
    ],
    onLayout: onLayout,
    children: [canRenderCanvas && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: canvasStyle.canvas,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_CornerRadii.CornerRadii, {
        width: finalWidth,
        height: finalHeight,
        style: props.style,
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.Rect, {
          x: 0,
          y: 0,
          width: finalWidth,
          height: finalHeight,
          color: backgroundColor,
          children: [isLinear && /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowLinearGradientFill.default, {
            width: finalWidth,
            height: finalHeight,
            ...props
          }), props.inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
            dx: shadowProps.shadowOffset.width,
            dy: shadowProps.shadowOffset.height,
            blur: shadowProps.shadowBlur,
            color: shadowProps.shadowColor,
            inner: true
          }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
            dx: shadowProps.reflectedLightOffset.width,
            dy: shadowProps.reflectedLightOffset.height,
            blur: shadowProps.reflectedLightBlur,
            color: shadowProps.reflectedLightColor,
            inner: true
          })]
        })
      })
    }), props.children]
  });
}

/**
 * ShadowView: for a basic “solid” background shadow
 * (no gradient props).
 */
function ShadowView(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowView, {
    ...props
  });
}

/**
 * LinearShadowView: for a linear gradient background shadow
 * (requires e.g. colors, from, to).
 */
function LinearShadowView(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(UnifiedShadowView, {
    ...props
  });
}
//# sourceMappingURL=ShadowView.js.map